@@ -27,11 +27,11 @@ class Form8x(SimpleNameFolder):
         if os.path.isdir(_code_dir):
             self.form.append(helper.json_read(_code_dir, 'form.json'))
             try:
-                encoding = helper.detect_by_bom(os.path.join(_code_dir, 'module.txt'), 'utf-8')
-                self.code['obj'] = self.read_raw_code(_code_dir, 'module.txt', encoding=encoding)
+                encoding = helper.detect_by_bom(os.path.join(_code_dir, 'module.bin'), 'utf-8')
+                self.code['obj'] = self.read_raw_code(_code_dir, 'module.bin', encoding=encoding)
             except UnicodeDecodeError:
                 encoding = 'windows-1251'
-                self.code['obj'] = self.read_raw_code(_code_dir, 'module.txt', encoding=encoding)
+                self.code['obj'] = self.read_raw_code(_code_dir, 'module.bin', encoding=encoding)
             self.header['code_encoding_obj'] = encoding  # можно безболезненно поменять на utf-8-sig
             self.header[f'code_info_obj'] = 1
 
@@ -81,4 +81,4 @@ class Form8x(SimpleNameFolder):
             os.makedirs(_code_dir, exist_ok=True)
             helper.json_write(self.form[0], _code_dir, 'form.json')
             _encoding = self.header.get('code_encoding_obj', 'utf-8-sig')
-            self.write_raw_code(self.code.get('obj', ''), _code_dir, 'module.txt', encoding=_encoding)
+            self.write_raw_code(self.code.get('obj', ''), _code_dir, 'module.bin', encoding=_encoding)
