@@ -34,12 +34,16 @@ class JsonContainerDecoder:
         _src_path = os.path.join(src_dir, file_name)
         self = cls(src_dir=src_dir, file_name=file_name)
         encoding = None
+        read_as_byte = False
         try:
             with open(os.path.join(src_dir, file_name), 'r', encoding='utf-8-sig') as entry_file:  # replace BOM
                 try:
-                    json.load(entry_file)  # если в файле чистый json воспринимаем его как текстовый файл
-                    entry_file.seek(0)
-                    data = entry_file.read()
+                    if entry_file.read(1) == '{':
+                        entry_file.seek(0)
+                        json.load(entry_file)  # если в файле чистый json воспринимаем его как бинарный файл
+                        read_as_byte = True
+                    else:
+                        read_as_byte = True
                 except json.JSONDecodeError as err:
                     entry_file.seek(0)
                     data = self.decode_file(entry_file)
@@ -49,10 +53,12 @@ class JsonContainerDecoder:
                     data = self.decode_file(entry_file)
                     encoding = 'windows-1251'
             except UnicodeDecodeError:
-                with open(os.path.join(src_dir, file_name), 'rb') as entry_file:
-                    data = entry_file.read()
+                read_as_byte = True
         except Exception as err:
             raise ExtException(parent=err, message=f'Json decode {file_name} error: {err}')
+        if read_as_byte:
+            with open(os.path.join(src_dir, file_name), 'rb') as entry_file:
+                data = entry_file.read()
 
         if dest_dir is not None:
             if isinstance(data, list):
@@ -73,8 +79,21 @@ class JsonContainerDecoder:
     def decode_file(self, file):
         self.mode = READ_PARAM
         self.data = []
+        i = 1
         for line in file:
-            self.decode_line(line)
+            try:
+                self.decode_line(line)
+                i += 1
+            except Exception as err:
+                raise ExtException(
+                    parent=err,
+                    message="Ошибка при разборе скобкофайла",
+                    detail=f'{os.path.basename(self.src_dir)}/{self.file_name} упало на строке {i}',
+                    dump=dict(
+                        mode=self.mode,
+                        current_object=self.current_object,
+                        path=self.path
+                    ))
         if not self.data:
             return ''
         return self.data
@@ -115,11 +134,7 @@ class JsonContainerDecoder:
                     raise Exception(
                         f'неожиданное начало объекта file:{self.src_dir}/{self.file_name}, path:{self.path})')
         elif self.mode == BEGIN_READ_STRING_VALUE:
-            if line.endswith('",\n') and not line.endswith('"",\n'):
-                self.current_value += line[:-2]
-                self._end_value()
-            else:
-                self.current_value += line
+            self.decode_object(line)
         elif self.mode == READ_B64:
             if line == '\n':
                 return
@@ -188,7 +203,8 @@ class JsonContainerDecoder:
     def _end_current_object(self):
         self.mode = READ_PARAM
         self._end_value()
-        self.path.pop()
+        if self.path:  # могут быль лишние закрывающие скобки
+            self.path.pop()
         self.current_object = self.path[-1] if self.path else None
         self.current_value = None
 
